@@ -213,7 +213,7 @@ class Launch(BaseModel):
                               'window_end': 'windowend',
                               'net': 'net', 'infoURLs': 'info_urls', 'vidURLs': 'vid_urls',
                               'holdreason': 'holdreason', 'failreason': 'failreason', 'probability': 'probability',
-                              'hashtag': 'hashtag', 'lsp': 'agency', 'changed': 'changed', 'location': 'location',
+                              'hashtag': 'hashtag', 'lsp': 'agency', 'changed': 'changed', 'pad': 'pad',
                               'rocket': 'rocket', 'missions': 'missions'}
 
         self.id = None
@@ -233,7 +233,7 @@ class Launch(BaseModel):
         self.hashtag = None
         self._lsp = None
         self.changed = None
-        self.location = None
+        self.pad = None
         self.rocket = None
         self.missions = None
 
